// File created from ../../../src/lib/cache/cache_messages.mes on Fri Jun 07 2013 10:16

#include <cstddef>
#include <log/message_types.h>
#include <log/message_initializer.h>

namespace isc {
namespace cache {

extern const isc::log::MessageID CACHE_ENTRY_MISSING_RRSET = "CACHE_ENTRY_MISSING_RRSET";
extern const isc::log::MessageID CACHE_LOCALZONE_FOUND = "CACHE_LOCALZONE_FOUND";
extern const isc::log::MessageID CACHE_LOCALZONE_UNKNOWN = "CACHE_LOCALZONE_UNKNOWN";
extern const isc::log::MessageID CACHE_LOCALZONE_UPDATE = "CACHE_LOCALZONE_UPDATE";
extern const isc::log::MessageID CACHE_MESSAGES_DEINIT = "CACHE_MESSAGES_DEINIT";
extern const isc::log::MessageID CACHE_MESSAGES_EXPIRED = "CACHE_MESSAGES_EXPIRED";
extern const isc::log::MessageID CACHE_MESSAGES_FOUND = "CACHE_MESSAGES_FOUND";
extern const isc::log::MessageID CACHE_MESSAGES_INIT = "CACHE_MESSAGES_INIT";
extern const isc::log::MessageID CACHE_MESSAGES_REMOVE = "CACHE_MESSAGES_REMOVE";
extern const isc::log::MessageID CACHE_MESSAGES_UNCACHEABLE = "CACHE_MESSAGES_UNCACHEABLE";
extern const isc::log::MessageID CACHE_MESSAGES_UNKNOWN = "CACHE_MESSAGES_UNKNOWN";
extern const isc::log::MessageID CACHE_MESSAGES_UPDATE = "CACHE_MESSAGES_UPDATE";
extern const isc::log::MessageID CACHE_RESOLVER_DEEPEST = "CACHE_RESOLVER_DEEPEST";
extern const isc::log::MessageID CACHE_RESOLVER_INIT = "CACHE_RESOLVER_INIT";
extern const isc::log::MessageID CACHE_RESOLVER_INIT_INFO = "CACHE_RESOLVER_INIT_INFO";
extern const isc::log::MessageID CACHE_RESOLVER_LOCAL_MSG = "CACHE_RESOLVER_LOCAL_MSG";
extern const isc::log::MessageID CACHE_RESOLVER_LOCAL_RRSET = "CACHE_RESOLVER_LOCAL_RRSET";
extern const isc::log::MessageID CACHE_RESOLVER_LOOKUP_MSG = "CACHE_RESOLVER_LOOKUP_MSG";
extern const isc::log::MessageID CACHE_RESOLVER_LOOKUP_RRSET = "CACHE_RESOLVER_LOOKUP_RRSET";
extern const isc::log::MessageID CACHE_RESOLVER_NO_QUESTION = "CACHE_RESOLVER_NO_QUESTION";
extern const isc::log::MessageID CACHE_RESOLVER_UNKNOWN_CLASS_MSG = "CACHE_RESOLVER_UNKNOWN_CLASS_MSG";
extern const isc::log::MessageID CACHE_RESOLVER_UNKNOWN_CLASS_RRSET = "CACHE_RESOLVER_UNKNOWN_CLASS_RRSET";
extern const isc::log::MessageID CACHE_RESOLVER_UPDATE_MSG = "CACHE_RESOLVER_UPDATE_MSG";
extern const isc::log::MessageID CACHE_RESOLVER_UPDATE_RRSET = "CACHE_RESOLVER_UPDATE_RRSET";
extern const isc::log::MessageID CACHE_RESOLVER_UPDATE_UNKNOWN_CLASS_MSG = "CACHE_RESOLVER_UPDATE_UNKNOWN_CLASS_MSG";
extern const isc::log::MessageID CACHE_RESOLVER_UPDATE_UNKNOWN_CLASS_RRSET = "CACHE_RESOLVER_UPDATE_UNKNOWN_CLASS_RRSET";
extern const isc::log::MessageID CACHE_RRSET_EXPIRED = "CACHE_RRSET_EXPIRED";
extern const isc::log::MessageID CACHE_RRSET_INIT = "CACHE_RRSET_INIT";
extern const isc::log::MessageID CACHE_RRSET_LOOKUP = "CACHE_RRSET_LOOKUP";
extern const isc::log::MessageID CACHE_RRSET_NOT_FOUND = "CACHE_RRSET_NOT_FOUND";
extern const isc::log::MessageID CACHE_RRSET_REMOVE_OLD = "CACHE_RRSET_REMOVE_OLD";
extern const isc::log::MessageID CACHE_RRSET_UNTRUSTED = "CACHE_RRSET_UNTRUSTED";
extern const isc::log::MessageID CACHE_RRSET_UPDATE = "CACHE_RRSET_UPDATE";

} // namespace cache
} // namespace isc

namespace {

const char* values[] = {
    "CACHE_ENTRY_MISSING_RRSET", "missing RRset to generate message for %1",
    "CACHE_LOCALZONE_FOUND", "found entry with key %1 in local zone data",
    "CACHE_LOCALZONE_UNKNOWN", "entry with key %1 not found in local zone data",
    "CACHE_LOCALZONE_UPDATE", "updating local zone element at key %1",
    "CACHE_MESSAGES_DEINIT", "deinitialized message cache",
    "CACHE_MESSAGES_EXPIRED", "found an expired message entry for %1 in the message cache",
    "CACHE_MESSAGES_FOUND", "found a message entry for %1 in the message cache",
    "CACHE_MESSAGES_INIT", "initialized message cache for %1 messages of class %2",
    "CACHE_MESSAGES_REMOVE", "removing old instance of %1/%2/%3 first",
    "CACHE_MESSAGES_UNCACHEABLE", "not inserting uncacheable message %1/%2/%3",
    "CACHE_MESSAGES_UNKNOWN", "no entry for %1 found in the message cache",
    "CACHE_MESSAGES_UPDATE", "updating message entry %1/%2/%3",
    "CACHE_RESOLVER_DEEPEST", "looking up deepest NS for %1/%2",
    "CACHE_RESOLVER_INIT", "initializing resolver cache for class %1",
    "CACHE_RESOLVER_INIT_INFO", "initializing resolver cache for class %1",
    "CACHE_RESOLVER_LOCAL_MSG", "message for %1/%2 found in local zone data",
    "CACHE_RESOLVER_LOCAL_RRSET", "RRset for %1/%2 found in local zone data",
    "CACHE_RESOLVER_LOOKUP_MSG", "looking up message in resolver cache for %1/%2",
    "CACHE_RESOLVER_LOOKUP_RRSET", "looking up RRset in resolver cache for %1/%2",
    "CACHE_RESOLVER_NO_QUESTION", "answer message for %1/%2 has empty question section",
    "CACHE_RESOLVER_UNKNOWN_CLASS_MSG", "no cache for class %1",
    "CACHE_RESOLVER_UNKNOWN_CLASS_RRSET", "no cache for class %1",
    "CACHE_RESOLVER_UPDATE_MSG", "updating message for %1/%2/%3",
    "CACHE_RESOLVER_UPDATE_RRSET", "updating RRset for %1/%2/%3",
    "CACHE_RESOLVER_UPDATE_UNKNOWN_CLASS_MSG", "no cache for class %1",
    "CACHE_RESOLVER_UPDATE_UNKNOWN_CLASS_RRSET", "no cache for class %1",
    "CACHE_RRSET_EXPIRED", "found expired RRset %1/%2/%3",
    "CACHE_RRSET_INIT", "initializing RRset cache for %1 RRsets of class %2",
    "CACHE_RRSET_LOOKUP", "looking up %1/%2/%3 in RRset cache",
    "CACHE_RRSET_NOT_FOUND", "no RRset found for %1/%2/%3 in cache",
    "CACHE_RRSET_REMOVE_OLD", "removing old RRset for %1/%2/%3 to make space for new one",
    "CACHE_RRSET_UNTRUSTED", "not replacing old RRset for %1/%2/%3, it has higher trust level",
    "CACHE_RRSET_UPDATE", "updating RRset %1/%2/%3 in the cache",
    NULL
};

const isc::log::MessageInitializer initializer(values);

} // Anonymous namespace

