// File created from ../../../src/lib/resolve/resolve_messages.mes on Fri Jun 07 2013 10:16

#include <cstddef>
#include <log/message_types.h>
#include <log/message_initializer.h>

namespace isc {
namespace resolve {

extern const isc::log::MessageID RESLIB_ANSWER = "RESLIB_ANSWER";
extern const isc::log::MessageID RESLIB_CNAME = "RESLIB_CNAME";
extern const isc::log::MessageID RESLIB_DEEPEST = "RESLIB_DEEPEST";
extern const isc::log::MessageID RESLIB_EMPTY_RESPONSE = "RESLIB_EMPTY_RESPONSE";
extern const isc::log::MessageID RESLIB_ERROR_RESPONSE = "RESLIB_ERROR_RESPONSE";
extern const isc::log::MessageID RESLIB_EXTRADATA_RESPONSE = "RESLIB_EXTRADATA_RESPONSE";
extern const isc::log::MessageID RESLIB_FOLLOW_CNAME = "RESLIB_FOLLOW_CNAME";
extern const isc::log::MessageID RESLIB_INVALID_NAMECLASS_RESPONSE = "RESLIB_INVALID_NAMECLASS_RESPONSE";
extern const isc::log::MessageID RESLIB_INVALID_QNAME_RESPONSE = "RESLIB_INVALID_QNAME_RESPONSE";
extern const isc::log::MessageID RESLIB_INVALID_TYPE_RESPONSE = "RESLIB_INVALID_TYPE_RESPONSE";
extern const isc::log::MessageID RESLIB_LONG_CHAIN = "RESLIB_LONG_CHAIN";
extern const isc::log::MessageID RESLIB_MULTIPLE_CLASS_RESPONSE = "RESLIB_MULTIPLE_CLASS_RESPONSE";
extern const isc::log::MessageID RESLIB_NOTSINGLE_RESPONSE = "RESLIB_NOTSINGLE_RESPONSE";
extern const isc::log::MessageID RESLIB_NOT_ONE_QNAME_RESPONSE = "RESLIB_NOT_ONE_QNAME_RESPONSE";
extern const isc::log::MessageID RESLIB_NOT_RESPONSE = "RESLIB_NOT_RESPONSE";
extern const isc::log::MessageID RESLIB_NO_NS_RRSET = "RESLIB_NO_NS_RRSET";
extern const isc::log::MessageID RESLIB_NSAS_LOOKUP = "RESLIB_NSAS_LOOKUP";
extern const isc::log::MessageID RESLIB_NXDOM_NXRR = "RESLIB_NXDOM_NXRR";
extern const isc::log::MessageID RESLIB_OPCODE_RESPONSE = "RESLIB_OPCODE_RESPONSE";
extern const isc::log::MessageID RESLIB_PROTOCOL = "RESLIB_PROTOCOL";
extern const isc::log::MessageID RESLIB_PROTOCOL_RETRY = "RESLIB_PROTOCOL_RETRY";
extern const isc::log::MessageID RESLIB_RCODE_RETURNED = "RESLIB_RCODE_RETURNED";
extern const isc::log::MessageID RESLIB_RECQ_CACHE_FIND = "RESLIB_RECQ_CACHE_FIND";
extern const isc::log::MessageID RESLIB_RECQ_CACHE_NO_FIND = "RESLIB_RECQ_CACHE_NO_FIND";
extern const isc::log::MessageID RESLIB_REFERRAL = "RESLIB_REFERRAL";
extern const isc::log::MessageID RESLIB_REFER_ZONE = "RESLIB_REFER_ZONE";
extern const isc::log::MessageID RESLIB_RESOLVE = "RESLIB_RESOLVE";
extern const isc::log::MessageID RESLIB_RRSET_FOUND = "RESLIB_RRSET_FOUND";
extern const isc::log::MessageID RESLIB_RTT = "RESLIB_RTT";
extern const isc::log::MessageID RESLIB_RUNQ_CACHE_FIND = "RESLIB_RUNQ_CACHE_FIND";
extern const isc::log::MessageID RESLIB_RUNQ_CACHE_LOOKUP = "RESLIB_RUNQ_CACHE_LOOKUP";
extern const isc::log::MessageID RESLIB_RUNQ_FAIL = "RESLIB_RUNQ_FAIL";
extern const isc::log::MessageID RESLIB_RUNQ_SUCCESS = "RESLIB_RUNQ_SUCCESS";
extern const isc::log::MessageID RESLIB_TCP_TRUNCATED = "RESLIB_TCP_TRUNCATED";
extern const isc::log::MessageID RESLIB_TEST_SERVER = "RESLIB_TEST_SERVER";
extern const isc::log::MessageID RESLIB_TEST_UPSTREAM = "RESLIB_TEST_UPSTREAM";
extern const isc::log::MessageID RESLIB_TIMEOUT = "RESLIB_TIMEOUT";
extern const isc::log::MessageID RESLIB_TIMEOUT_RETRY = "RESLIB_TIMEOUT_RETRY";
extern const isc::log::MessageID RESLIB_TRUNCATED = "RESLIB_TRUNCATED";
extern const isc::log::MessageID RESLIB_UPSTREAM = "RESLIB_UPSTREAM";

} // namespace resolve
} // namespace isc

namespace {

const char* values[] = {
    "RESLIB_ANSWER", "answer received in response to query for <%1>",
    "RESLIB_CNAME", "CNAME received in response to query for <%1>",
    "RESLIB_DEEPEST", "did not find <%1> in cache, deepest delegation found is %2",
    "RESLIB_EMPTY_RESPONSE", "empty response received to query for <%1>",
    "RESLIB_ERROR_RESPONSE", "unspecified error received in response to query for <%1>",
    "RESLIB_EXTRADATA_RESPONSE", "extra data in response to query for <%1>",
    "RESLIB_FOLLOW_CNAME", "following CNAME chain to <%1>",
    "RESLIB_INVALID_NAMECLASS_RESPONSE", "invalid name or class in response to query for <%1>",
    "RESLIB_INVALID_QNAME_RESPONSE", "invalid name or class in response to query for <%1>",
    "RESLIB_INVALID_TYPE_RESPONSE", "invalid name or class in response to query for <%1>",
    "RESLIB_LONG_CHAIN", "CNAME received in response to query for <%1>: CNAME chain length exceeded",
    "RESLIB_MULTIPLE_CLASS_RESPONSE", "response to query for <%1> contained multiple RRsets with different classes",
    "RESLIB_NOTSINGLE_RESPONSE", "response to query for <%1> was not a response",
    "RESLIB_NOT_ONE_QNAME_RESPONSE", "not one question in response to query for <%1>",
    "RESLIB_NOT_RESPONSE", "response to query for <%1> was not a response",
    "RESLIB_NO_NS_RRSET", "no NS RRSet in referral response received to query for <%1>",
    "RESLIB_NSAS_LOOKUP", "looking up nameserver for zone %1 in the NSAS",
    "RESLIB_NXDOM_NXRR", "NXDOMAIN/NXRRSET received in response to query for <%1>",
    "RESLIB_OPCODE_RESPONSE", "response to query for <%1> did not have query opcode",
    "RESLIB_PROTOCOL", "protocol error in answer for %1:  %3",
    "RESLIB_PROTOCOL_RETRY", "protocol error in answer for %1: %2 (retries left: %3)",
    "RESLIB_RCODE_RETURNED", "response to query for <%1> returns RCODE of %2",
    "RESLIB_RECQ_CACHE_FIND", "found <%1> in the cache (resolve() instance %2)",
    "RESLIB_RECQ_CACHE_NO_FIND", "did not find <%1> in the cache, starting RunningQuery (resolve() instance %2)",
    "RESLIB_REFERRAL", "referral received in response to query for <%1>",
    "RESLIB_REFER_ZONE", "referred to zone %1",
    "RESLIB_RESOLVE", "asked to resolve <%1> (resolve() instance %2)",
    "RESLIB_RRSET_FOUND", "found single RRset in the cache when querying for <%1> (resolve() instance %2)",
    "RESLIB_RTT", "round-trip time of last query calculated as %1 ms",
    "RESLIB_RUNQ_CACHE_FIND", "found <%1> in the cache",
    "RESLIB_RUNQ_CACHE_LOOKUP", "looking up <%1> in the cache",
    "RESLIB_RUNQ_FAIL", "failure callback - nameservers are unreachable",
    "RESLIB_RUNQ_SUCCESS", "success callback - sending query to %1",
    "RESLIB_TCP_TRUNCATED", "TCP response to query for %1 was truncated",
    "RESLIB_TEST_SERVER", "setting test server to %1(%2)",
    "RESLIB_TEST_UPSTREAM", "sending upstream query for <%1> to test server at %2",
    "RESLIB_TIMEOUT", "query <%1> to %2 timed out",
    "RESLIB_TIMEOUT_RETRY", "query <%1> to %2 timed out, re-trying (retries left: %3)",
    "RESLIB_TRUNCATED", "response to query for <%1> was truncated, re-querying over TCP",
    "RESLIB_UPSTREAM", "sending upstream query for <%1> to %2",
    NULL
};

const isc::log::MessageInitializer initializer(values);

} // Anonymous namespace

